@@ -63,6 +63,7 @@ class Products extends CGExtensions
   var $_hierarchy_cache;
   var $_category_cache;
   var $_admin_loaded;
+  var $_flddef_cache;
 
   public function __construct()
   {
@@ -117,7 +118,7 @@ class Products extends CGExtensions
 
   function GetVersion()
   {
-	return '2.11';
+	return '2.12.1';
   }
 
   function MinimumCMSVersion()
@@ -492,47 +493,52 @@ EOT;
   // deprecated
   function GetFieldDefs($admin = false,$public = true)
   {
-	$entryarray = array();
+	if( !is_array($this->_fflddef_cache) )
+	  {
+		$entryarray = array();
+		$db = cmsms()->GetDB();
 		
-	global $gCms;
-	$db =& $gCms->GetDB();
-		
-	if( $admin == true && $public == true )
-	  {
-		$query = 'SELECT * FROM '.cms_db_prefix().'module_products_fielddefs ORDER BY item_order';
-	  }
-	else if( $public == true )
-	  {
-		$query = 'SELECT * FROM '.cms_db_prefix().'module_products_fielddefs WHERE public > 0 ORDER BY item_order';
-	  }
-	else
-	  {
-		$query = 'SELECT * FROM '.cms_db_prefix().'module_products_fielddefs WHERE admin_only <= 0 ORDER BY item_order';
-	  }
-	$dbresult = $db->Execute($query);
-
-	while ($dbresult && $row = $dbresult->FetchRow())
-	  {
-		$onerow = new stdClass();
-			
-		$onerow->id = $row['id'];
-		$onerow->name = $row['name'];
-		$onerow->prompt = $row['prompt'];
-		$onerow->type = $row['type'];
-		$tmp = explode("\n",$row['options']);
-		$tmp2 = array();
-		foreach( $tmp as $one )
+		if( $admin == true && $public == true )
 		  {
-			$one = trim($one);
-			$tmp2[$one] = $one;
+			$query = 'SELECT * FROM '.cms_db_prefix().'module_products_fielddefs ORDER BY item_order';
 		  }
-		$onerow->options = $tmp2;
-		$onerow->max_length = $row['max_length'];
-			
-		$entryarray[] = $onerow;
-	  }
+		else if( $public == true )
+		  {
+			$query = 'SELECT * FROM '.cms_db_prefix().'module_products_fielddefs WHERE public > 0 ORDER BY item_order';
+		  }
+		else
+		  {
+			$query = 'SELECT * FROM '.cms_db_prefix().'module_products_fielddefs WHERE admin_only <= 0 ORDER BY item_order';
+		  }
+		$dbresult = $db->GetArray($query);
 		
-	return $entryarray;
+		if( is_array($dbresult) )
+		  {
+			foreach( $dbresult as $row )
+			  {
+				$onerow = new stdClass();
+				
+				$onerow->id = $row['id'];
+				$onerow->name = $row['name'];
+				$onerow->prompt = $row['prompt'];
+				$onerow->type = $row['type'];
+				$tmp = explode("\n",$row['options']);
+				$tmp2 = array();
+				foreach( $tmp as $one )
+				  {
+					$one = trim($one);
+					$tmp2[$one] = $one;
+				  }
+				$onerow->options = $tmp2;
+				$onerow->max_length = $row['max_length'];
+				
+				$entryarray[] = $onerow;
+			  }
+		  }
+		$this->_flddef_cache = $entryarray;
+	  }
+
+	return $this->_flddef_cache;
   }
 
 
@@ -696,7 +702,7 @@ EOT;
   // deprecated
   function GetProductAttributeDataComplete($product_id)
   {
-	$db =& $this->GetDb();
+	$db = $this->GetDb();
 	$data = array();
 
 	$query = 'SELECT * FROM '.cms_db_prefix().'module_products_attribsets
