@@ -485,13 +485,19 @@ while ($dbresult && ($row = $dbresult->FetchRow()))
       $onerow->categorynames = $catnamearray;
     }
 
-  // add attributes
+  // add attributes ... deprecated.
   $tmp = $this->GetProductAttributeDataComplete($row['id']);
   if( is_array($tmp) )
     {
       $onerow->attributes = $tmp;
     }
 
+  $tmp = product_utils::get_product_attributes_full($params['product_id']);
+  if( is_array($tmp) )
+    {
+      $onerow->attribs_full = $tmp;
+    }
+
   $entryarray[] = $onerow;
 }
 
