@@ -109,13 +109,19 @@ if ( $row )
     $onerow->hierarchy_id = product_ops::get_product_hierarchy_id($params['productid']);
     $onerow->breadcrumb = product_ops::create_hierarchy_breadcrumb($id,$params['productid'],$returnid);
 
-    // add attributes
+    // add attributes... this is deprecated.
     $tmp = $this->GetProductAttributeDataComplete($params['productid']);
     if( is_array($tmp) )
       {
 	$onerow->attributes = $tmp;
       }
 
+    $tmp = product_utils::get_product_attributes_full($params['product_id']);
+    if( is_array($tmp) )
+      {
+	$onerow->attribs_full = $tmp;
+      }
+
     // add categories
     $catarray = $this->GetCategoriesForProduct($params['productid'],true,true);
     $catnamearray = array();
