@@ -105,6 +105,7 @@ $lang['error_product_nameused'] = 'A product by that name already exists';
 $lang['error_product_notfound'] = 'The requested product could not be found';
 $lang['error_product_skuused'] = 'That SKU value is already in use by another product';
 $lang['error_price_adjustment'] = 'Invalid price adjustment value for item %s';
+$lang['error_sku_required'] = 'Please enter a unique SKU';
 $lang['error_upload_failed'] = 'Upload failed: %s';
 $lang['expire_six_months'] = 'After Six Months';
 $lang['expire_one_year'] = 'After One Year';
@@ -395,6 +396,7 @@ $lang['prompt_hierpage'] = 'Default Page for Hierarchy View';
 $lang['prompt_prettyhierurls'] = 'Use Pretty URLS to Hierarchy Views';
 $lang['prompt_prod_detailpage'] = 'Default Page for Product Detail Views';
 $lang['prompt_products_matching'] = 'Products matching %s';
+$lang['prompt_sku_required'] = 'SKU is required for all products and attributes';
 $lang['prompt_summarypagelimit'] = 'Default page limit in summary mode';
 $lang['prompt_summarysortorder'] = 'Default Sort Order in summary mode';
 $lang['prompt_summarysorting'] = 'Default Sort Field in summary mode';
