@@ -94,6 +94,7 @@ $lang['error_product_nameused'] = 'Er bestaat al een product met deze naam';
 $lang['error_product_notfound'] = 'Het gevraagde product kan niet worden gevonden';
 $lang['error_product_skuused'] = 'Deze Uitlevereenheid is al in gebruik door een ander product';
 $lang['error_price_adjustment'] = 'Ongeldige prijs aanpassing van item %s';
+$lang['error_sku_required'] = 'Voer een unieke SKU in';
 $lang['error_upload_failed'] = 'Upload mislukt: %s';
 $lang['expire_six_months'] = 'Na zes maanden';
 $lang['expire_one_year'] = 'Na een jaar';
@@ -214,10 +215,10 @@ $lang['info_duplicateproducts'] = 'Specificeer hoe het systeem moet handelen als
 $lang['info_fielddefs_tab'] = '<strong>Opmerking:</strong> De hier aanwezige velden zijn beschikbaar voor alle producten.';
 $lang['info_fieldproblems'] = 'Er is probleem ontstaan met het verwerken van een of meer aangemaakte velden.  Deze actie is correct uitgevoerd. maar het is verstandig alles te controleren en eventueel te herstellen.';
 $lang['info_handleimages'] = 'Upon import, if an image filename is found in a field column, should it be moved from the source location, watermarked, thumbnailed, and the field type changed to &quot;image&quot;';
-$lang['info_hierpage'] = 'Use this page for hierarchy views.  The pageid will not be spefiried on the URL.';
-$lang['info_imagepath'] = 'The path (relative to the uploads directory) where images referred to in the import file, can be found';
+$lang['info_hierpage'] = 'Gebruik deze pagina voor de hie&auml;rchische weergave. De paginaid zal niet worden weergegeven in de URL.';
+$lang['info_imagepath'] = 'In dit pad (gezien vanaf de uploads-map) kunnen de afbeeldingen worden gevonden die zijn opgegeven in het ge&iuml;mporteerde bestand.';
 $lang['info_import_test_passed'] = 'Een korte test heeft plaatsgevonden op het geselecteerde geselecteerde bestand en alles lijkt in orde.<br/>Dit is echter geen garantie dat er geen fouten in het bestand aanwezig zijn.';
-$lang['info_prettyhierurls'] = 'Include the hierarchy item name on the URL';
+$lang['info_prettyhierurls'] = 'Voeg de hie&auml;rchie naam toe aan de URL';
 $lang['info_price_adjustment'] = 'Geaccepteerde waarden zijn +-*#.##';
 $lang['info_prodnotfound'] = 'This option determines the behaviour of the website if a product detail view is accessed directly by URL, and that product for whatever reason (disabled, deleted, etc) cannot be accessed.';
 $lang['info_publicfield'] = 'Publieke velden zijn zichtbaar voor het publiek';
@@ -258,10 +259,12 @@ $lang['param_action'] = 'Specificeer de werking van de module.  Mogelijke waarde
 
 </ul>';
 $lang['param_category'] = 'When used in the <em>default</em> summary mode, this parameter, which should match the name of an existing category will be used to display only those products that are in that categoory. (a comma seperated list can be supplied)';
+$lang['param_categoryfield'] = 'Applicable only to the &quot;categorylist&quot; action, this parameter can be used to filter categories based on the value of a category field.  It will not work in conjunction with the &quot;category&quot; or &quot;category_id&quot; parameters.   The syntax of this parameter is a comma separated list of field names, and field values.  i.e:  categorylist=&quot;field name:value,field name 2:value 2&quot;';
 $lang['param_categorylisttemplate'] = 'Useful only with the categorylist action, this parameter indicates the template that should be used for the display.  If no value is specified then the current default template of that type is used.';
 $lang['param_categorylistdtltemplate'] = 'Useful only with the categorylist actions, this parameter indicates the template that should be used for the display of the category details.  This uses a category list template..  If no value is specified then the current default template of that type is used.';
 $lang['param_detailpage'] = 'This specifies the pageid or alias that should be used to display the detail report.';
 $lang['param_detailtemplate'] = 'This parameter specifies the template that should be used for the detail mode display.  If no value is specified, then the current default template of that type is used.';
+$lang['param_excludecat'] = 'Applicable only to the default (summary) view, this parameter will allow excluding products that are in a specific category from the result. A comma separated list of category names is allowed. This parameter can work in conjunction with the category parameter to provide a list of the products that are in this category, but not in that category';
 $lang['param_field'] = 'Used only in the <em>fieldlist</em> action, this parameter is required to specify the name of a user defined property to create a list from.';
 $lang['param_fieldval'] = 'Used only in the <em>default</em> action, this parameter allows specifying a field value to limit results by.  Special values for this field are &quot;::null::&quot; &quot;::notnull::&quot;';
 $lang['param_hierarchy'] = 'Useful only in the <em>default</em> action, this parameter specifies that only items in that location of the hierarchy should be displayed.  Wildcard character can be used so that you can specify parent/child relationships as well.  i.e {Products hierarchy=&#039;trucks*&#039;} will create a summary report of all trucks, including the children in the hierarchy.  Similarly, {Products hierarchy=&#039;*trucks&#039;} will display a summary report of all trucks, and all products beloging to any parent in the hierarchy.';
@@ -272,8 +275,8 @@ $lang['param_parent'] = 'Useful only in the <em>hierarchy</em> action, this para
 $lang['param_productid'] = 'Heeft alleen zin in de uitgebreide sjabloon. Deze parameter geeft aan welk product te gebruiken bij het weergeven.';
 $lang['param_productlist'] = 'Applicable only to the default (summary) view, this parameter allows specifying a comma separated list of integer product ids to display.  No pagination or sorting is performed on these values, and if specified the other filtering parameters to the summary view are ignored.';
 $lang['param_resultpage'] = 'Applicable only to the search action, this parameter specifies a page id or alias to use to display the search results';
-$lang['param_searchfield'] = 'Applicable only to the search action, this parameter may contain a comma separated list of field names to include in the search';
-$lang['param_searchformtemplate'] = 'Applicable only to the search action, thisparameter allows specifying a non default search form template';
+$lang['param_searchfield'] = 'Alleen van toepassing op de zoekacties, deze parameter kan een kommagescheiden lijst bevatten met daarin veldnamen die kunnen worden toegevoegd in de zoekactie.';
+$lang['param_searchformtemplate'] = 'Alleen van toepassing op de zoekacties, deze parameter staat nu om een niet standaard zoeksjabloon te gebruiken';
 $lang['param_showall'] = 'Applicable only to the categorylist action, if this parameter is set to a non 0 integer value all categories (even those without products) will be displayed.';
 $lang['param_sortorder'] = 'Specify the order of sorted fields in summary view.  Possible values are:
 <ul>
@@ -353,6 +356,7 @@ $lang['prompt_hierpage'] = 'Standaard pagina voor hie&auml;rchische weergave';
 $lang['prompt_prettyhierurls'] = 'Gebruik Pretty URL&#039;s voor de hie&auml;rchische weergave';
 $lang['prompt_prod_detailpage'] = 'Standaard Pagina voor Product Detail Overzichten';
 $lang['prompt_products_matching'] = 'Producten gelijk aan %s';
+$lang['prompt_sku_required'] = 'Een SKU is vereist voor alle producten en attributen';
 $lang['prompt_summarypagelimit'] = 'Standaard paginalimiet in samenvattingsmodus';
 $lang['prompt_summarysortorder'] = 'Standaard sorteervolgorde in samenvattingsmodus';
 $lang['prompt_summarysorting'] = 'Standaard veldvolgorde in samenvattingsmodus';
@@ -417,8 +421,8 @@ $lang['viewable_fields'] = 'Selecteer velden om in het tabel te tonen';
 $lang['watermark_location'] = 'Plaats Watermerk';
 $lang['weight'] = 'Gewicht';
 $lang['yes'] = 'Ja';
-$lang['utma'] = '156861353.1852221271.1287479092.1297233296.1297405951.112';
-$lang['utmz'] = '156861353.1297192927.110.70.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/';
+$lang['utma'] = '156861353.1852221271.1287479092.1305382006.1305392937.148';
+$lang['utmz'] = '156861353.1305382016.147.92.utmcsr=feedburner|utmccn=Feed: cmsmadesimple/blog (CMS Made Simple)|utmcmd=feed';
 $lang['qca'] = 'P0-161031897-1287479092171';
 $lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
