@@ -39,6 +39,8 @@
 
 class product_utils
 {
+  protected function __construct() {}
+
   static public function get_field_types($selectone = false)
   {
     $mod = cge_utils::get_module('Products');
@@ -184,6 +186,41 @@ class product_utils
     return FALSE;
   }
 
+
+  public static function get_product_attributes_full($product_id)
+  {
+    $db = cmsms()->GetDb();
+    $data = array();
+
+    $query = 'SELECT * FROM '.cms_db_prefix().'module_products_attribsets
+              WHERE product_id = ?';
+    $tmp = $db->GetArray($query,array($product_id));	
+
+    $tmp2 = cge_array::extract_field($tmp,'attrib_set_id');
+    $q2 = 'SELECT * FROM '.cms_db_prefix().'module_products_attributes
+            WHERE attrib_set_id IN ('.implode(',',$tmp2).') ORDER BY attrib_set_id ASC';
+    $tmp3 = $db->GetArray($q2);
+
+    for( $i = 0; $i < count($tmp); $i++ )
+      {
+	$row =& $tmp[$i];
+
+	$attribs = array();
+	for( $j = 0; $j < count($tmp3); $j++ )
+	  {
+	    $row2 =& $tmp3[$j];
+	    if( $row2['attrib_set_id'] < $row['attrib_set_id'] ) continue;
+	    if( $row2['attrib_set_id'] > $row['attrib_set_id'] ) break;
+
+	    $attribs[$row2['attrib_text']] = $row2;
+	  }
+	$data[$row['attrib_set_name']] = $attribs;
+      }
+
+    if( !count($data) ) return false;
+    return $data;
+  }
+
 } // product opts
 
 #
